@@ -1,4 +1,5 @@
 import json
+import logging
 from .exceptions import (
     JSONRPCInvalidParams,
     JSONRPCInvalidRequest,
@@ -15,6 +16,8 @@ from .jsonrpc2 import (
 )
 from .jsonrpc import JSONRPCRequest
 
+logger = logging.getLogger(__name__)
+
 
 class JSONRPCResponseManager(object):
 
@@ -89,7 +92,6 @@ class JSONRPCResponseManager(object):
             try:
                 result = method(*request.args, **request.kwargs)
             except TypeError:
-                #import ipdb; ipdb.set_trace()  # XXX BREAKPOINT
                 yield response(error=JSONRPCInvalidParams()._data)
                 continue
             except Exception as e:
@@ -98,6 +100,7 @@ class JSONRPCResponseManager(object):
                     "args": e.args,
                     "message": str(e),
                 }
+                logger.exception("API Exception: {}".format(data))
                 yield response(error=JSONRPCServerError(data=data)._data)
                 continue
 
